<?php

namespace Drupal\media_migration;

/**
 * Interface of Media Migration's UUID oracle.
 */
interface MediaMigrationUuidOracleInterface {

  /**
   * Returns the UUID of a media entity based on its source ID.
   *
   * @param int $source_id
   *   The original ID of the media entity in the source database.
   *
   * @return string
   *   The UUID of the given media entity.
   *
   * @throws \Exception
   */
  public function getMediaUuid(int $source_id): string;

  /**
   * Returns the UUID prophecy if it exists.
   *
   * @param int $source_id
   *   The source media entity's identifier.
   *
   * @return string|null
   *   The UUID, or NULL if it does not exist at the moment.
   */
  public function getMediaUuidProphecy(int $source_id): ?string;

}
